% Example Motor Design 
% G(s)= 1/(s(1+sT))
% Time constant T=1
randn('state',0);
s=tf('s');
sysc=1/(s*(s+1));
h=0.2;
sysd=c2d(sysc,h);
[b,a]=tfdata(sysd);
b=b{1}; a=a{1};

% Minimum Variance Control (d=1)
b=b(2:3);
c=b; % Assume y=b/a*(u+w) input noise
c=[c 0];       % deg(C)=deg(A)
k=c(1); c=c/k; % C monic
[f,g]=deconv(c,a);
contr=tf(g,conv(b,f),h); % controller

clsys = sysd/(1+sysd*contr);
clsys = minreal(clsys);

% Simulate closed loop system
tmax=200;
e = randn(1,tmax);
y = lsim(clsys,e);
u = filter(-g,conv(b,f),y);

% Check the result, compare simulation vs theory
ycov_sim = cov(y)
cov_theory=k^2
ucov_sim=cov(u)

% Some plotting

frv = logspace(-2,0.4,1000);
frsysd = squeeze(freqresp(sysd,frv,'Hz'));
frcontr = squeeze(freqresp(contr,frv,'Hz'));
frL = squeeze(freqresp(contr*sysd,frv,'Hz'));

figure(1);
subplot(211)
plot(y,'linewidth',1.2);hold on
ylabel('y','fontsize',16);
axis([0 tmax -0.1 0.1]) 
subplot(212)
plot(u,'linewidth',1.2);hold on
ylabel('u','fontsize',16);

figure(2)
plot(frsysd,'linewidth',1.4); 
hold on; axis([-3 3 -3 3])
plot(frL,'k','linewidth',1.4); 
plot([-3 3],[0 0],'k')
plot([0 0],[-3 3],'k')
plot(-1,0,'k+','markersize',20)
legend('Process','Process*Controller')
title('Nyquist Curves, Minimal Variance','fontsize',16)
set(gca,'fontsize',16)

figure(3)
loglog(frv,abs(frsysd),'b','linewidth',1.4);hold on
loglog(frv,abs(frcontr),'r','linewidth',1.4);
loglog(frv,abs(frL),'k','linewidth',1.4);
legend('Process','Controller','L','Location','North')
title('Amplitude Curves, Minimal Variance','fontsize',16)
xlabel('Freqeuency [Hz]','fontsize',16)
ylabel('Gain','fontsize',16)
set(gca,'fontsize',16)

% figure(1), print -depsc motor1_1.eps
% figure(2), print -depsc motor1_2.eps
% figure(3), print -depsc motor1_3.eps







