function p = spfactd(b,a,rho)
% SPFACTD Spectral factorization of discrete-time polynomial
%
%         p = spfactd(b,a,rho)
%
%         Calculates p(z) in the spectral factorization 
%         
%            r p(z) p(1/z) = rho a(z) a(1/z) + b(z) b(1/z)
%
%         The routine only handles deg(a) > deg(b).

% Kjell Gustafsson
% LastEditDate : Tue Apr  7 09:09:44 1992
% Copyright (c) 1992 by Kjell Gustafsson and Department of Automatic Control,
% Lund Institute of Technology, Lund, SWEDEN


if length(a)<= length(b)
  error('deg(a) must be larger than deg(b)')
end

[Phi,Gam,C,D] = tf2ss(b,a);
L = dlqr(Phi,Gam,C'*C,rho*eye(size(Gam,2)));
[dummy,p] = ss2tf(Phi-Gam*L,Gam,C,D);
    


